
## load package geomorph v3.1.3 # Adams et al. 2019 ##

# Read in Lm data #
Droms.Lm<-readland.nts("Droms_Lm.dta")
rownames(Droms.Lm)<-paste("L",1:480,sep="")
colnames(Droms.Lm)<-c("x","y","z")

##########################################################

# Generate Surface & Curve Slm sliders matrices
CurvSliders<-as.matrix(read.csv("Drom_CurveSliders.csv",header=T))
SurfSliders<-as.matrix(read.csv("Drom_SurfSliders.csv",header=T))

# Label vectors #
Lab_1<-c("Anhima","Anseranas","Leipoa","D.planei","I.woodburnei","D.murrayi","Gallus")
Lab_2<-c("Gallus","Leipoa","Anhima","Anseranas","D.murrayi","D.planei","I.woodburnei")

##########################################################

# GPA #
Droms.Lm.Gpa<-gpagen(Droms.Lm,Proj=T,ProcD=F,PrinAxes=T,curves=CurvSliders,surfaces=SurfSliders)
rownames(Droms.Lm.Gpa$coords)<-paste("L",1:480,sep="")

##########################################################

## plot Lms & Slms on 3D ply objects ##

## NOTE: The following 3D plotting using the geomorph function 'plotspec' was conducted using R v3.6.1 and geomorph v3.1.3
## However, due to recent package updates (e.g. geomorph v3.3.1), the following code will not work if called in the current version ## 

# Full Lm suite (MS Fig. 2) #

# D. planei #
PlaneiPLY<-read.ply("D.planei.ply",ShowSpecimen=F,addNormals=F)
PlaneiPLY$material$color<-"#ffbbbb"
Planei.Digitdat<-data.frame(Droms.Lm[,,4])
row.names(Planei.Digitdat)<-paste(1:480,sep="")
Planei.Digitdat[111:200,]="NA"
# plot #
plotspec(spec=PlaneiPLY,digitspec=Planei.Digitdat,fixed=20,ptsize=NULL,centered=F,box=T,axes=F)

# Wlst LHS Links (MS Fig. 2D) #
Links.Wlst.LHS<-read.csv("Drom_Links_WlstLHS.csv")
Links.Wlst.LHS.M<-as.matrix(Links.Wlst.LHS,76,2,byrow=T)
# Plot #
plotRefToTarget(Droms.Lm[21:110,,4],Droms.Lm[21:110,,4],method="points",mag=1,
                links=Links.Wlst.LHS.M,gridPars=gridPar(pt.bg="green",pt.size=0.8,out.col="blue",
                                                        out.cex=0.5,tar.pt.bg="black",tar.pt.size=0.5,link.col="blue",
                                                        n.col.cell=30),axes=F)

##########################################################

## MS Fig. 7 ##

# Wlst Slm modules plotted on D.planei endocast (MS Figs. 7A) #
# Subset Wlst Slms #
Planei.Digitdat.Wlst<-data.frame(Droms.Lm[21:110,,4])
# Plot #
plotspec(spec=PlaneiPLY,digitspec=Planei.Digitdat.Wlst,fixed=NULL,ptsize=NULL,centered=F,box=F,axes=F)

## Modular Shape Variation plots for MS Figs. 7E-F, 7I-J, 7M-N ##
# Wlst Compl Links #
Links.Wlst.Compl<-read.csv("Drom_Links_WlstCompl.csv")
Links.Wlst.Compl.M<-as.matrix(Links.Wlst.Compl,152,2,byrow=T)

# Plots #
# D.planei vs D.murrayi (MS Figs. 7D) #
plotRefToTarget(Droms.Lm.Gpa$coords[21:110,,6],Droms.Lm.Gpa$coords[21:110,,4],method="points", 
                mag=1,links=Links.Wlst.Compl.M,gridPars=gridPar(pt.bg="gray",pt.size=0.5,out.col="gray",
                                                                out.cex=0.5,tar.pt.bg="black",tar.pt.size=0.5,
                                                                tar.link.col="blue",n.col.cell=30),axes=F)
# D.planei vs I.woodburnei (MS Figs. 7G) #
plotRefToTarget(Droms.Lm.Gpa$coords[21:110,,5],Droms.Lm.Gpa$coords[21:110,,4],method="points", 
                mag=1,links=Links.Wlst.Compl.M,gridPars=gridPar(pt.bg="gray",pt.size=0.5,out.col="gray",
                                                                out.cex=0.5,tar.pt.bg="black",tar.pt.size=0.5,
                                                                tar.link.col="blue",n.col.cell=30),axes=F)

# D.murrayi vs I.woodburnei (MS Figs. 7J) #
plotRefToTarget(Droms.Lm.Gpa$coords[21:110,,5],Droms.Lm.Gpa$coords[21:110,,6],method="points", 
                mag=1,links=Links.Wlst.Compl.M,gridPars=gridPar(pt.bg="gray",pt.size=0.5,out.col="gray",
                                                                out.cex=0.5,tar.pt.bg="black",tar.pt.size=0.5,
                                                                tar.link.col="blue",n.col.cell=30),axes=F)



# Wlst, Tel.C Cereb & Rhom Slm subsets plotted on D.planei endocast (MS Figs. 7B-C) #
# Subset Wlst, Tel.C, Cereb & Rhom Slms #
Planei.Digitdat.WlstTelCerRho<-data.frame(rbind(Droms.Lm[21:110,,4],Droms.Lm[201:290,,4],Droms.Lm[411:480,,4],
                                                deparse.level=1))
# Plot #
plotspec(spec=PlaneiPLY,digitspec=Planei.Digitdat.WlstTelCerRho,fixed=NULL,ptsize=NULL,centered=F,box=F,axes=F)

## Modular Shape Variation plots for MS Figs. 7E, 7H, 7K ##
# Links matrix #
Links.WlstTelCer<-read.csv("Drom_Links_WlstTelCer.csv")
Links.WlstTelCer.M<-as.matrix(Links.WlstTelCer,368,2,byrow=T)
# Subset Wlst + Tel.C + Cereb GPA coordinates #
Droms.comb.WlstTelCer<-combine.subsets(Droms.Lm.Gpa$coords[21:110,,4:6],Droms.Lm.Gpa$coords[201:290,,4:6],
                                       Droms.Lm.Gpa$coords[411:445,,4:6],gpa=F,CS.sets=NULL)
rownames(Droms.comb.WlstTelCer$coords)<-paste("L",sep="",(c(21:110,201:290,411:445)))

# Plots #
# D.planei vs D.murrayi (MS Fig. 7E) #
plotRefToTarget(Droms.comb.WlstTelCer$coords[,,3],Droms.comb.WlstTelCer$coords[,,1],method="points", 
                mag=1,links=Links.WlstTelCer.M,gridPars=gridPar(pt.bg="gray",pt.size=0.5,out.col="gray",
                                                                out.cex=0.5,tar.pt.bg="black",tar.pt.size=0.5,
                                                                tar.link.col="blue",n.col.cell=30),axes=F)
# D.planei vs I.woodburnei (MS Fig. 7H) #
plotRefToTarget(Droms.comb.WlstTelCer$coords[,,2],Droms.comb.WlstTelCer$coords[,,1],method="points", 
                mag=1,links=Links.WlstTelCer.M,gridPars=gridPar(pt.bg="gray",pt.size=0.5,out.col="gray",
                                                                out.cex=0.5,tar.pt.bg="black",tar.pt.size=0.5,
                                                                tar.link.col="blue",n.col.cell=30),axes=F)
# D.murrayi vs I.woodburnei (MS Fig. 7K) #
plotRefToTarget(Droms.comb.WlstTelCer$coords[,,2],Droms.comb.WlstTelCer$coords[,,3],method="points", 
                mag=1,links=Links.WlstTelCer.M,gridPars=gridPar(pt.bg="gray",pt.size=0.5,out.col="gray",
                                                                out.cex=0.5,tar.pt.bg="black",tar.pt.size=0.5,
                                                                tar.link.col="blue",n.col.cell=30),axes=F)

## Modular Shape Variation plots for MS Figs. 7F, 7I, 7L ##
# Wlst.R, Tel.C.R, Cereb & Rhom Links subsets #
Links.WlstTelCerRho.R<-read.csv("Drom_Links_WlstTelCerRho_RHS.csv")
Links.WlstTelCerRho.R.M<-as.matrix(Links.WlstTelCerRho.R,274,2,byrow=T)
# Subset Wlst + Tel.C + Cereb + Rho RHS GPA coordinates #
Droms.comb.WlstTelCerRho.R<-combine.subsets(Droms.Lm.Gpa$coords[66:110,,4:6],Droms.Lm.Gpa$coords[246:290,,4:6],
                                            Droms.Lm.Gpa$coords[411:480,,4:6],gpa=F,CS.sets=NULL)
rownames(Droms.comb.WlstTelCerRho.R$coords)<-paste("L",sep="",(c(66:110,246:290,411:480)))

# Plots #
# D.planei vs D.murrayi (MS Fig. 7F) #
plotRefToTarget(Droms.comb.WlstTelCerRho.R$coords[,,3],Droms.comb.WlstTelCerRho.R$coords[,,1],method="points", 
                mag=1,links=Links.WlstTelCerRho.R.M,gridPars=gridPar(pt.bg="gray",pt.size=0.5,out.col="gray",
                                                                     out.cex=0.5,tar.pt.bg="black",tar.pt.size=0.5,
                                                                     tar.link.col="blue",n.col.cell=30),axes=F)
# D.planei vs I.woodburnei (MS Fig. 7I) #
plotRefToTarget(Droms.comb.WlstTelCerRho.R$coords[,,2],Droms.comb.WlstTelCerRho.R$coords[,,1],method="points", 
                mag=1,links=Links.WlstTelCerRho.R.M,gridPars=gridPar(pt.bg="gray",pt.size=0.5,out.col="gray",
                                                                     out.cex=0.5,tar.pt.bg="black",tar.pt.size=0.5,
                                                                     tar.link.col="blue",n.col.cell=30),axes=F)
# D.murrayi vs I.woodburnei (MS Fig. 7L) #
plotRefToTarget(Droms.comb.WlstTelCerRho.R$coords[,,2],Droms.comb.WlstTelCerRho.R$coords[,,3],method="points", 
                mag=1,links=Links.WlstTelCerRho.R.M,gridPars=gridPar(pt.bg="gray",pt.size=0.5,out.col="gray",
                                                                     out.cex=0.5,tar.pt.bg="black",tar.pt.size=0.5,
                                                                     tar.link.col="blue",n.col.cell=30),axes=F)


##########################################################

## MS Table 1 ##

## Compute Modular Distance values ##

## Wlst LHS ##
# Wlst.L L #
Wlst.L.L.lmks<-matrix(c(39,40,40,41,41,42,42,43,43,44,44,45,45,46,46,47),ncol=2,byrow=T)
colnames(Wlst.L.L.lmks)<-c("start","end")
Wlst.L.L.ILD<-interlmkdist(Droms.Lm,Wlst.L.L.lmks)
Wlst.L.L<-matrix(rowSums(Wlst.L.L.ILD),1,7)
rownames(Wlst.L.L)<-c("Wlst.L.L")
colnames(Wlst.L.L)<-Lab_1
# Wlst.L W #
Wlst.L.W.lmks<-matrix(c(62,53,53,44,44,35,35,26),ncol=2,byrow=T)
colnames(Wlst.L.W.lmks)<-c("start","end")
Wlst.L.W.ILD<-interlmkdist(Droms.Lm,Wlst.L.W.lmks)
Wlst.L.W<-matrix(rowSums(Wlst.L.W.ILD),1,7)
rownames(Wlst.L.W)<-c("Wlst.L.W")
colnames(Wlst.L.W)<-Lab_1

## Wlst RHS ##
# Wlst.R L #
Wlst.R.L.lmks<-matrix(c(84,85,85,86,86,87,87,88,88,89,89,90,90,91,91,92),ncol=2,byrow=T)
colnames(Wlst.R.L.lmks)<-c("start","end")
Wlst.R.L.ILD<-interlmkdist(Droms.Lm,Wlst.R.L.lmks)
Wlst.R.L<-matrix(rowSums(Wlst.R.L.ILD),1,7)
rownames(Wlst.R.L)<-c("Wlst.R.L")
colnames(Wlst.R.L)<-Lab_1
# Wlst.L W #
Wlst.R.W.lmks<-matrix(c(71,80,80,89,89,98,98,107),ncol=2,byrow=T)
colnames(Wlst.R.W.lmks)<-c("start","end")
Wlst.R.W.ILD<-interlmkdist(Droms.Lm,Wlst.R.W.lmks)
Wlst.R.W<-matrix(rowSums(Wlst.R.W.ILD),1,7)
rownames(Wlst.R.W)<-c("Wlst.R.W")
colnames(Wlst.R.W)<-Lab_1

## Tel.R LHS ##
# Tel.R.L L #
Tel.R.L.L.lmks<-matrix(c(138,139,139,140,140,141,141,142,142,143,143,144,144,145,145,146),ncol=2,byrow=T)
colnames(Tel.R.L.L.lmks)<-c("start","end")
Tel.R.L.L.ILD<-interlmkdist(Droms.Lm,Tel.R.L.L.lmks)
Tel.R.L.L<-matrix(rowSums(Tel.R.L.L.ILD),1,7)
rownames(Tel.R.L.L)<-c("Tel.R.L.L")
colnames(Tel.R.L.L)<-Lab_1
# Tel.R.L W #
Tel.R.L.W.lmks<-matrix(c(151,142,142,133,133,124,124,115),ncol=2,byrow=T)
colnames(Tel.R.L.W.lmks)<-c("start","end")
Tel.R.L.W.ILD<-interlmkdist(Droms.Lm,Tel.R.L.W.lmks)
Tel.R.L.W<-matrix(rowSums(Tel.R.L.W.ILD),1,7)
rownames(Tel.R.L.W)<-c("Tel.R.L.W")
colnames(Tel.R.L.W)<-Lab_1

## Tel.R RHS ##
# Tel.R.R L #
Tel.R.R.L.lmks<-matrix(c(183,184,184,185,185,186,186,187,187,188,188,189,189,190,190,191),ncol=2,byrow=T)
colnames(Tel.R.R.L.lmks)<-c("start","end")
Tel.R.R.L.ILD<-interlmkdist(Droms.Lm,Tel.R.R.L.lmks)
Tel.R.R.L<-matrix(rowSums(Tel.R.R.L.ILD),1,7)
rownames(Tel.R.R.L)<-c("Tel.R.R.L")
colnames(Tel.R.R.L)<-Lab_1
# Tel.R.R W #
Tel.R.R.W.lmks<-matrix(c(196,187,187,178,178,169,169,160),ncol=2,byrow=T)
colnames(Tel.R.R.W.lmks)<-c("start","end")
Tel.R.R.W.ILD<-interlmkdist(Droms.Lm,Tel.R.R.W.lmks)
Tel.R.R.W<-matrix(rowSums(Tel.R.R.W.ILD),1,7)
rownames(Tel.R.R.W)<-c("Tel.R.R.W")
colnames(Tel.R.R.W)<-Lab_1

## Tel.C LHS ##
# Tel.C.L L #
Tel.C.L.L.lmks<-matrix(c(219,220,220,221,221,222,222,223,223,224,224,225,225,226,226,227),ncol=2,byrow=T)
colnames(Tel.C.L.L.lmks)<-c("start","end")
Tel.C.L.L.ILD<-interlmkdist(Droms.Lm,Tel.C.L.L.lmks)
Tel.C.L.L<-matrix(rowSums(Tel.C.L.L.ILD),1,7)
rownames(Tel.C.L.L)<-c("Tel.C.L.L")
colnames(Tel.C.L.L)<-Lab_1
# Tel.C.L W #
Tel.C.L.W.lmks<-matrix(c(241,232,232,223,223,214,214,205),ncol=2,byrow=T)
colnames(Tel.C.L.W.lmks)<-c("start","end")
Tel.C.L.W.ILD<-interlmkdist(Droms.Lm,Tel.C.L.W.lmks)
Tel.C.L.W<-matrix(rowSums(Tel.C.L.W.ILD),1,7)
rownames(Tel.C.L.W)<-c("Tel.C.L.W")
colnames(Tel.C.L.W)<-Lab_1

## Tel.C RHS ##
# Tel.C.R L #
Tel.C.R.L.lmks<-matrix(c(264,265,265,266,266,267,267,268,268,269,269,270,270,271,271,272),ncol=2,byrow=T)
colnames(Tel.C.R.L.lmks)<-c("start","end")
Tel.C.R.L.ILD<-interlmkdist(Droms.Lm,Tel.C.R.L.lmks)
Tel.C.R.L<-matrix(rowSums(Tel.C.R.L.ILD),1,7)
rownames(Tel.C.R.L)<-c("Tel.C.R.L")
colnames(Tel.C.R.L)<-Lab_1
# Tel.C.R W #
Tel.C.R.W.lmks<-matrix(c(286,277,277,268,268,259,259,250),ncol=2,byrow=T)
colnames(Tel.C.R.W.lmks)<-c("start","end")
Tel.C.R.W.ILD<-interlmkdist(Droms.Lm,Tel.C.R.W.lmks)
Tel.C.R.W<-matrix(rowSums(Tel.C.R.W.ILD),1,7)
rownames(Tel.C.R.W)<-c("Tel.C.R.W")
colnames(Tel.C.R.W)<-Lab_1

## Opt LHS ##
# Opt.L L #
Opt.L.L.lmks<-matrix(c(303,304,304,305,305,306,306,307,307,308),ncol=2,byrow=T)
colnames(Opt.L.L.lmks)<-c("start","end")
Opt.L.L.ILD<-interlmkdist(Droms.Lm,Opt.L.L.lmks)
Opt.L.L<-matrix(rowSums(Opt.L.L.ILD),1,7)
rownames(Opt.L.L)<-c("Opt.L.L")
colnames(Opt.L.L)<-Lab_1
# Opt.L W #
Opt.L.W.lmks<-matrix(c(294,300,300,306,306,312,312,318),ncol=2,byrow=T)
colnames(Opt.L.W.lmks)<-c("start","end")
Opt.L.W.ILD<-interlmkdist(Droms.Lm,Opt.L.W.lmks)
Opt.L.W<-matrix(rowSums(Opt.L.W.ILD),1,7)
rownames(Opt.L.W)<-c("Opt.L.W")
colnames(Opt.L.W)<-Lab_1

## Opt RHS ##
# Opt.R L #
Opt.R.L.lmks<-matrix(c(333,334,334,335,335,336,336,337,337,338),ncol=2,byrow=T)
colnames(Opt.R.L.lmks)<-c("start","end")
Opt.R.L.ILD<-interlmkdist(Droms.Lm,Opt.R.L.lmks)
Opt.R.L<-matrix(rowSums(Opt.R.L.ILD),1,7)
rownames(Opt.R.L)<-c("Opt.R.L")
colnames(Opt.R.L)<-Lab_1
# Opt.R W #
Opt.R.W.lmks<-matrix(c(324,330,330,336,336,342,342,348),ncol=2,byrow=T)
colnames(Opt.R.W.lmks)<-c("start","end")
Opt.R.W.ILD<-interlmkdist(Droms.Lm,Opt.R.W.lmks)
Opt.R.W<-matrix(rowSums(Opt.R.W.ILD),1,7)
rownames(Opt.R.W)<-c("Opt.R.W")
colnames(Opt.R.W)<-Lab_1

## Tri.g LHS ##
# Tri.g.L L #
Tri.g.L.L.lmks<-matrix(c(352,355,355,358,358,361,361,364,364,376,376,373,373,370,370,367),ncol=2,byrow=T)
colnames(Tri.g.L.L.lmks)<-c("start","end")
Tri.g.L.L.ILD<-interlmkdist(Droms.Lm,Tri.g.L.L.lmks)
Tri.g.L.L<-matrix(rowSums(Tri.g.L.L.ILD),1,7)
rownames(Tri.g.L.L)<-c("Tri.g.L.L")
colnames(Tri.g.L.L)<-Lab_1
# Tri.g.L W #
Tri.g.L.W.lmks<-matrix(c(363,364,364,365),ncol=2,byrow=T)
colnames(Tri.g.L.W.lmks)<-c("start","end")
Tri.g.L.W.ILD<-interlmkdist(Droms.Lm,Tri.g.L.W.lmks)
Tri.g.L.W<-matrix(rowSums(Tri.g.L.W.ILD),1,7)
rownames(Tri.g.L.W)<-c("Tri.g.L.W")
colnames(Tri.g.L.W)<-Lab_1

## Tri.g RHS ##
# Tri.g.R L #
Tri.g.R.L.lmks<-matrix(c(382,385,385,388,388,391,391,394,394,406,406,403,403,400,400,397),ncol=2,byrow=T)
colnames(Tri.g.R.L.lmks)<-c("start","end")
Tri.g.R.L.ILD<-interlmkdist(Droms.Lm,Tri.g.R.L.lmks)
Tri.g.R.L<-matrix(rowSums(Tri.g.R.L.ILD),1,7)
rownames(Tri.g.R.L)<-c("Tri.g.R.L")
colnames(Tri.g.R.L)<-Lab_1
# Tri.g.R W #
Tri.g.R.W.lmks<-matrix(c(393,394,394,395),ncol=2,byrow=T)
colnames(Tri.g.R.W.lmks)<-c("start","end")
Tri.g.R.W.ILD<-interlmkdist(Droms.Lm,Tri.g.R.W.lmks)
Tri.g.R.W<-matrix(rowSums(Tri.g.R.W.ILD),1,7)
rownames(Tri.g.R.W)<-c("Tri.g.R.W")
colnames(Tri.g.R.W)<-Lab_1

## Cer ##
# Cer W #
Cereb.W.lmks<-matrix(c(431,430,430,429,429,428,428,427,427,426,426,425),ncol=2,byrow=T)
colnames(Cereb.W.lmks)<-c("start","end")
Cereb.W.ILD<-interlmkdist(Droms.Lm,Cereb.W.lmks)
Cereb.W<-matrix(rowSums(Cereb.W.ILD),1,7)
rownames(Cereb.W)<-c("Cereb.W")
colnames(Cereb.W)<-Lab_1
# Cer L #
Cereb.L.lmks<-matrix(c(414,421,421,428,428,435,435,442),ncol=2,byrow=T)
colnames(Cereb.L.lmks)<-c("start","end")
Cereb.L.ILD<-interlmkdist(Droms.Lm,Cereb.L.lmks)
Cereb.L<-matrix(rowSums(Cereb.L.ILD),1,7)
rownames(Cereb.L)<-c("Cereb.L")
colnames(Cereb.L)<-Lab_1

## Rho ##
# Rho L #
Rhomb.L.lmks<-matrix(c(460,461,461,462,462,463,463,464,464,465,465,466),ncol=2,byrow=T)
colnames(Rhomb.L.lmks)<-c("start","end")
Rhomb.L.ILD<-interlmkdist(Droms.Lm,Rhomb.L.lmks)
Rhomb.L<-matrix(rowSums(Rhomb.L.ILD),1,7)
rownames(Rhomb.L)<-c("Rhomb.L")
colnames(Rhomb.L)<-Lab_1
# Rho W #
Rhomb.W.lmks<-matrix(c(477,470,470,463,463,456,456,449),ncol=2,byrow=T)
colnames(Rhomb.W.lmks)<-c("start","end")
Rhomb.W.ILD<-interlmkdist(Droms.Lm,Rhomb.W.lmks)
Rhomb.W<-matrix(rowSums(Rhomb.W.ILD),1,7)
rownames(Rhomb.W)<-c("Rhomb.W")
colnames(Rhomb.W)<-Lab_1

## Tel.C Total Width ##
Tel.C.TW.lmks<-matrix(c(223,268),ncol=2,byrow=T)
colnames(Tel.C.TW.lmks)<-c("start","end")
Tel.C.TW.ILD<-interlmkdist(Droms.Lm,Tel.C.TW.lmks)
Tel.C.TW<-matrix(rowSums(Tel.C.TW.ILD),1,7)
rownames(Tel.C.TW)<-c("Tel.C.TW")
colnames(Tel.C.TW)<-Lab_1

## Meten Total Height ##
Meten.TH.lmks<-matrix(c(435,463),ncol=2,byrow=T)
colnames(Meten.TH.lmks)<-c("start","end")
Meten.TH.ILD<-interlmkdist(Droms.Lm,Meten.TH.lmks)
Meten.TH<-matrix(rowSums(Meten.TH.ILD),1,7)
rownames(Meten.TH)<-c("Meten.TH")
colnames(Meten.TH)<-Lab_1

## Med.Ob Total Width ##
Med.Ob.TW.lmks<-matrix(c(12,13),ncol=2,byrow=T)
colnames(Med.Ob.TW.lmks)<-c("start","end")
Med.Ob.TW.ILD<-interlmkdist(Droms.Lm,Med.Ob.TW.lmks)
Med.Ob.TW<-matrix(rowSums(Med.Ob.TW.ILD),1,7)
rownames(Med.Ob.TW)<-c("Med.Ob.TW")
colnames(Med.Ob.TW)<-Lab_1

# Write ILD Results #
Droms.Dist.ILD<-matrix(c(Wlst.L.L,Wlst.L.W,Wlst.R.L,Wlst.R.W,Tel.R.L.L,Tel.R.L.W,Tel.R.R.L,
                         Tel.R.R.W,Tel.C.L.L,Tel.C.L.W,Tel.C.R.L,Tel.C.R.W,Opt.L.L,
                         Opt.L.W,Opt.R.L,Opt.R.W,Tri.g.L.L,Tri.g.L.W,Tri.g.R.L,Tri.g.R.W,Cereb.L,
                         Cereb.W,Rhomb.L,Rhomb.W,Tel.C.TW,Meten.TH,Med.Ob.TW),27,7,byrow=T)
rownames(Droms.Dist.ILD)<-c("Wlst.L.L","Wlst.L.W","Wlst.R.L","Wlst.R.W","Tel.r.L.L","Tel.r.L.W","Tel.r.R.L","Tel.r.R.W",
                            "Tel.c.L.L","Tel.c.L.W","Tel.c.R.L","Tel.c.R.W","Opt.L.L","Opt.L.W","Opt.R.L","Opt.R.W",
                            "Tri.g.L.L","Tri.g.L.W","Tri.g.R.L","Tri.g.R.W","Cer.L","Cer.W","Rho.L","Rho.W","Tel.c.TW",
                            "Meten.TH","Med.Ob.TW")
colnames(Droms.Dist.ILD)<-Lab_1

## Compile Table ##
Droms.Dist.Table<-cbind(Droms.Dist.ILD[,7],Droms.Dist.ILD[,3],Droms.Dist.ILD[,1],Droms.Dist.ILD[,2],
                        Droms.Dist.ILD[,6],Droms.Dist.ILD[,4],Droms.Dist.ILD[,5],deparse.level=1)
colnames(Droms.Dist.Table)<-Lab_2

# Compute means for paired modular structures (i.e. Wlst, Tel.r, Tel.c, Opt, Tri.g)
Wlst.L<-c((Droms.Dist.Table[1,1:7]+Droms.Dist.Table[3,1:7])/2)
Wlst.W<-c((Droms.Dist.Table[2,1:7]+Droms.Dist.Table[4,1:7])/2)
Tel.r.L<-c((Droms.Dist.Table[5,1:7]+Droms.Dist.Table[7,1:7])/2)
Tel.r.W<-c((Droms.Dist.Table[6,1:7]+Droms.Dist.Table[8,1:7])/2)
Tel.c.L<-c((Droms.Dist.Table[9,1:7]+Droms.Dist.Table[11,1:7])/2)
Tel.c.W<-c((Droms.Dist.Table[10,1:7]+Droms.Dist.Table[12,1:7])/2)
Opt.L<-c((Droms.Dist.Table[13,1:7]+Droms.Dist.Table[15,1:7])/2)
Opt.W<-c((Droms.Dist.Table[14,1:7]+Droms.Dist.Table[16,1:7])/2)
Tri.g.L<-c((Droms.Dist.Table[17,1:7]+Droms.Dist.Table[19,1:7])/2)
Tri.g.W<-c((Droms.Dist.Table[18,1:7]+Droms.Dist.Table[20,1:7])/2)

# complile Table including means #
Droms.Dist.ILD.1<-matrix(c(Wlst.L,Wlst.W,Tel.r.L,Tel.r.W,Tel.c.L,Tel.c.W,Opt.L,Opt.W,Tri.g.L,Tri.g.W),10,7,byrow=T)
rownames(Droms.Dist.ILD.1)<-c("Wlst.L","Wlst.W","Tel.r.L","Tel.r.W","Tel.c.L","Tel.c.W","Opt.L","Opt.W","Tri.g.L","Tri.g.W")
colnames(Droms.Dist.ILD.1)<-Lab_2
# read in endocast volume data #
Endo.Vol<-read.csv("Drom_EndoVol.csv",row.names=1)
Droms.Dist.Table<-rbind(Droms.Dist.ILD.1,Droms.Dist.Table[21:27,],t(Endo.Vol),deparse.level=1)
Droms.Dist.Table[3:4,5:7]<-(NA)
# write Table to file #
write.csv(Droms.Dist.Table,file="Table.1A.csv",quote=F)

##########################################################

## Log Shape Ratios # Sherratt et al. 2017 ##

## Distance data ##

# complile data set #
Droms.Dist.data<-cbind(Endo.Vol,t(Droms.Dist.Table.S1A[1:17,]),deparse.level=1)
# Compute Log Shape Ratios (MS Table 1B) #
Droms.Dist.ShR.Table<-t(log10(Droms.Dist.data[,-1]/apply(Droms.Dist.data[,-1],1,prod)^(1/ncol(Droms.Dist.data[,-1]))))
Droms.Dist.ShR.Table[3:4,5:7]<-(NA)
# write Table to file #
write.csv(Droms.Dist.ShR.Table,file="Table.1B.csv",quote=F)

## Surface Area data ##

# read in data #
Endo.Surf<-read.csv("Drom_EndoSurf.csv",row.names=1)
# compile data set #
Droms.Surf.data<-t(rbind(Endo.Surf[8,],Endo.Surf[1:7,],deparse.level=1))
# Compute Log Shape Ratios (MS Table.1D) #
Droms.Surf.ShR.Table<-t(log10(Droms.Surf.data[,-1]/apply(Droms.Surf.data[,-1],1,prod)^(1/ncol(Droms.Surf.data[,-1]))))
Droms.Surf.ShR.Table[2,5:7]<-(NA)
# write Table to file #
write.csv(Droms.Surf.ShR.Table,file="Table.1D.csv",quote=F)

##########################################################

## Supplementary Information ##

# SI, Fig. S11 # Anhima #
AnhimaPLY<-read.ply("Anhima.ply",ShowSpecimen=F,addNormals=F)
AnhimaPLY$material$color<-"#ffbbbb"
Anhima.Digitdat<-data.frame(Droms.Lm[,,1])
row.names(Anhima.Digitdat)<-paste(1:480,sep="")
# plot #
plotspec(spec=AnhimaPLY,digitspec=Anhima.Digitdat,fixed=20,ptsize=NULL,centered=F,box=F,axes=F)

# Estimated Body mass, Gizzard Mass and Size ratios (SI, Table S1B) #

Droms.Giz<-read.csv("Drom_Gizzard.csv",row.names=1)
Droms.Giz.LT<-log10(Droms.Giz)
GS.Ratios<-c(Droms.Giz.LT[,1]/Droms.Giz.LT[,3])
GM.Ratios<-c(Droms.Giz.LT[,2]/Droms.Giz.LT[,3])
Droms.Giz.Rat<-cbind(GS.Ratios,GM.Ratios,Droms.Giz.LT,deparse.level=1)
# write Table to file #
write.csv(Droms.Giz.Rat,file="Table.S1B.csv",quote=F)

## Gizzard Boxplot (SI Fig. S15) ##
# Palette #
colBox<-c("#87CEEBFF","#F0E68CFF")

windows(width=5.4,height=5.8)
boxplot(Droms.Giz.Ratios[1:5,2],Droms.Giz.Ratios[1:5,1],Droms.Giz.Ratios[6,2],Droms.Giz.Ratios[6,1],
        Droms.Giz.Ratios[7,2],Droms.Giz.Ratios[7,1],Droms.Giz.Ratios[8:9,2],Droms.Giz.Ratios[8:9,1],
        col=colBox,las=2,cex.axis=0.8,xlab=NULL,cex.lab=0.9,frame.plot=T)
axis(1,at=c(1:8),labels=c("GM","GS","GM","GS","GM","GS","GM","GS"),cex.axis=0.8,las=1)
legend("bottomleft",legend=c("GM Ratios","GS Ratios"),pch=c(22,22,NA),pt.cex=1.8,pt.bg=colBox, 
       col="black",bg="white",ncol=1,cex=0.7,bty="n",xpd=T,inset=c(0.018,0.0))
legend("bottom",legend=c("  Dinornis","Euryapteryx","Dromaius","Genyornis"),ncol=1, 
       cex=0.8,bty="n",xpd=T, horiz=T,text.width=c(1.55,1.65,1.0,1.43),inset=c(-0.17,-0.17))
abline(v=4.5,col="#808080",lty=2,lwd=1)
with(text(x=c(1),y=c(1.779349),cex=0.6,labels=c("20118"),pos=1))
with(text(x=c(2),y=c(0.858584),cex=0.6,labels=c("20118"),pos=3))
segments(x0=1,y0=1.624454,x1=3,y1=1.342193,col="#6495EDFF",lwd=1.5)
segments(x0=3,y0=1.342193,x1=5,y1=1.465486,col="#6495EDFF",lwd=1.5)
segments(x0=5,y0=1.465486,x1=7,y1=1.263021,col="#6495EDFF",lwd=1.5)
segments(x0=2,y0=0.7460041,x1=4,y1=0.5638975,col="#D2B48CFF",lwd=1.5)
segments(x0=4,y0=0.5638975,x1=6,y1=0.8166193,col="#D2B48CFF",lwd=1.5)
segments(x0=6,y0=0.8166193,x1=8,y1=0.4951136,col="#D2B48CFF",lwd=1.5)

##########################################################

